==> vtigercrm-5.2.1.tgz: cron/language/phpmailer.lang-de.php <==
<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
* ("License"); You may not use this file except in compliance with the License
* The Original Code is:  vtiger CRM Open Source
* The Initial Developer of the Original Code is vtiger.
* Portions created by vtiger are Copyright (C) vtiger.
* All Rights Reserved.
*
********************************************************************************/

/**
 * PHPMailer language file.
 * English Version
 */
$PHPMAILER_LANG = array();
$PHPMAILER_LANG["provide_address"] = 'Wenigstens eine ' .
                                     'Empfnger E-mail Adresse ist erforderlich.';
$PHPMAILER_LANG["mailer_not_supported"] = ' Mailer wird nicht untersttzt.';
$PHPMAILER_LANG["execute"] = 'Folgendes konnte nicht ausgefhrt werden: ';
$PHPMAILER_LANG["instantiate"] = 'Die Mail Funktion konnte nicht initialisiert werden.';
$PHPMAILER_LANG["authenticate"] = 'SMTP Fehler: keine Authentifizierung mglich.';
$PHPMAILER_LANG["from_failed"] = 'Die folgende Von Adresse ist fehlerhaft: ';
$PHPMAILER_LANG["recipients_failed"] = 'SMTP Fehler: Die folgende ' .
                                       'Empfngerangaben sind fehlerhaft: ';
$PHPMAILER_LANG["data_not_accepted"] = 'SMTP Fehler: Daten wurden nicht akzeptiert.';
$PHPMAILER_LANG["connect_host"] = 'SMTP Fehler: Konnte nicht den SMTP Host verbinden.';
$PHPMAILER_LANG["file_access"] = 'Auf die folgende Datei konnte nicht zugegriffen werden: ';
$PHPMAILER_LANG["file_open"] = 'Dateifehler: Datei konnte nicht geffnet werden: ';
$PHPMAILER_LANG["encoding"] = 'Unbekannte Kodierung: ';
?>

==> vtigercrm-5.4.0.tgz: cron/language/phpmailer.lang-de.php <==
<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
* ("License"); You may not use this file except in compliance with the License
* The Original Code is:  vtiger CRM Open Source
* The Initial Developer of the Original Code is vtiger.
* Portions created by vtiger are Copyright (C) vtiger.
* All Rights Reserved.
*
********************************************************************************/

/**
 * PHPMailer language file.
 * German Version
 */
$PHPMAILER_LANG = array();
$PHPMAILER_LANG["provide_address"] = 'Wenigstens eine Empfänger E-mail Adresse ist erforderlich.';
$PHPMAILER_LANG["mailer_not_supported"] = ' Mailer wird nicht unterstützt.';
$PHPMAILER_LANG["execute"] = 'Folgendes konnte nicht ausgeführt werden: ';
$PHPMAILER_LANG["instantiate"] = 'Die Mail Funktion konnte nicht initialisiert werden.';
$PHPMAILER_LANG["authenticate"] = 'SMTP Fehler: keine Authentifizierung möglich.';
$PHPMAILER_LANG["from_failed"] = 'Die folgende Von Adresse ist fehlerhaft: ';
$PHPMAILER_LANG["recipients_failed"] = 'SMTP Fehler: Die folgende Empfängerangaben sind fehlerhaft: ';
$PHPMAILER_LANG["data_not_accepted"] = 'SMTP Fehler: Daten wurden nicht akzeptiert.';
$PHPMAILER_LANG["connect_host"] = 'SMTP Fehler: Konnte nicht den SMTP Host verbinden.';
$PHPMAILER_LANG["file_access"] = 'Auf die folgende Datei konnte nicht zugegriffen werden: ';
$PHPMAILER_LANG["file_open"] = 'Dateifehler: Datei konnte nicht geöffnet werden: ';
$PHPMAILER_LANG["encoding"] = 'Unbekannte Kodierung: ';
?>
